.. :changelog:

.. _KeepAChangelog: http://keepachangelog.com/
.. _SemanticVersioning: http://semver.org/

Change Log
----------

All notable changes to this project will be documented in this file.

The format is based on KeepAChangelog_ and this project adheres to SemanticVersioning_.


[0.1.2] - 2017-03-10
++++++++++++++++++++

Added
~~~~~
* User-defined spots (EntityExtraction.UserDefinedSpots())


[0.1.1] - 2017-03-10
++++++++++++++++++++

Fixed
~~~~~
* PyPI version release


[0.1.0] - 2017-03-10
++++++++++++++++++++

* First release on PyPI.
